<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="ru_RU">
<context>
    <name>AlbumInfoWidget</name>
    <message>
        <source>Title</source>
        <translation type="obsolete">Название</translation>
    </message>
    <message>
        <source>Description</source>
        <translation type="obsolete">Описание</translation>
    </message>
    <message>
        <source>Creation time</source>
        <translation type="obsolete">Создан</translation>
    </message>
    <message>
        <source>Update time</source>
        <translation type="obsolete">Обновлен</translation>
    </message>
    <message>
        <location filename="../src/widgets/albuminfowidget.cpp" line="18"/>
        <source>Title:</source>
        <translation>Название:</translation>
    </message>
    <message>
        <location filename="../src/widgets/albuminfowidget.cpp" line="21"/>
        <source>Description:</source>
        <translation>Описание:</translation>
    </message>
    <message>
        <location filename="../src/widgets/albuminfowidget.cpp" line="24"/>
        <source>Created:</source>
        <translation>Создан:</translation>
    </message>
    <message>
        <location filename="../src/widgets/albuminfowidget.cpp" line="27"/>
        <source>Updated:</source>
        <translation>Обновлен:</translation>
    </message>
</context>
<context>
    <name>AlbumSelectDialog</name>
    <message>
        <location filename="../src/widgets/albumselectdialog.ui" line="14"/>
        <source>Select album</source>
        <translation>Выбор альбома</translation>
    </message>
</context>
<context>
    <name>FilterFriendGender</name>
    <message>
        <source>Male</source>
        <translation type="obsolete">Мужской</translation>
    </message>
    <message>
        <source>Female</source>
        <translation type="obsolete">Женский</translation>
    </message>
</context>
<context>
    <name>FilterFriendOnline</name>
    <message>
        <source>Online</source>
        <translation type="obsolete">В сети</translation>
    </message>
</context>
<context>
    <name>FilterMessageReaded</name>
    <message>
        <source>New</source>
        <translation type="obsolete">Новые</translation>
    </message>
</context>
<context>
    <name>FilterMessageType</name>
    <message>
        <source>All messages</source>
        <translation type="obsolete">Все сообщения</translation>
    </message>
    <message>
        <source>Inbox</source>
        <translation type="obsolete">Входящие</translation>
    </message>
    <message>
        <source>Sent</source>
        <translation type="obsolete">Отправленные</translation>
    </message>
    <message>
        <source>Drafts</source>
        <translation type="obsolete">Черновики</translation>
    </message>
</context>
<context>
    <name>Friend</name>
    <message>
        <source>Unknown</source>
        <translation type="obsolete">Неизвестный</translation>
    </message>
</context>
<context>
    <name>ImageBrowserPanel</name>
    <message>
        <location filename="../src/panels/imagebrowserpanel.ui" line="20"/>
        <source>Form</source>
        <translation>Панель изображений</translation>
    </message>
    <message>
        <source>People</source>
        <translation type="obsolete">Друзья</translation>
    </message>
    <message>
        <location filename="../src/panels/imagebrowserpanel.cpp" line="113"/>
        <location filename="../src/panels/imagebrowserpanel.cpp" line="451"/>
        <source>People (%1)</source>
        <translation>Друзья (%1)</translation>
    </message>
    <message>
        <source>News</source>
        <translation type="obsolete">Новости</translation>
    </message>
    <message>
        <source>News (%1)</source>
        <translation type="obsolete">Обновления (%1)</translation>
    </message>
    <message>
        <source>Type a name...</source>
        <translation type="obsolete">Введите имя...</translation>
    </message>
    <message numerus="yes">
        <location filename="../src/panels/imagebrowserpanel.cpp" line="296"/>
        <source>%1 photo(s)</source>
        <translation>
            <numerusform>%1 изображение</numerusform>
            <numerusform>%1 изображения</numerusform>
            <numerusform>%1 изображений</numerusform>
        </translation>
    </message>
    <message>
        <location filename="../src/panels/imagebrowserpanel.cpp" line="298"/>
        <source> Updated: </source>
        <translation> Обновлен: </translation>
    </message>
    <message>
        <location filename="../src/panels/imagebrowserpanel.cpp" line="325"/>
        <source>Album(s):</source>
        <translation>Альбом(ы):</translation>
    </message>
    <message>
        <location filename="../src/panels/imagebrowserpanel.cpp" line="398"/>
        <source>Photo(s):</source>
        <translation>Изображения:</translation>
    </message>
    <message numerus="yes">
        <location filename="../src/panels/imagebrowserpanel.cpp" line="409"/>
        <source>%1 photo(s):</source>
        <translation>
            <numerusform>%1 изображение:</numerusform>
            <numerusform>%1 изображения:</numerusform>
            <numerusform>%1 изображений:</numerusform>
        </translation>
    </message>
    <message>
        <source>No Friends</source>
        <translation type="obsolete">Нет друзей</translation>
    </message>
    <message>
        <source>Download friend list</source>
        <translation type="obsolete">Загрузка списка друзей</translation>
    </message>
    <message>
        <source>Online</source>
        <translation type="obsolete">В сети</translation>
    </message>
    <message>
        <location filename="../src/panels/imagebrowserpanel.cpp" line="291"/>
        <source>Untitled album</source>
        <translation>Безымянный альбом</translation>
    </message>
    <message>
        <location filename="../src/panels/imagebrowserpanel.cpp" line="501"/>
        <location filename="../src/panels/imagebrowserpanel.cpp" line="963"/>
        <source>No albums</source>
        <translation>Нет альбомов</translation>
    </message>
    <message>
        <location filename="../src/panels/imagebrowserpanel.cpp" line="503"/>
        <location filename="../src/panels/imagebrowserpanel.cpp" line="961"/>
        <source>Download albums</source>
        <translation>Загрузка альбомов</translation>
    </message>
    <message>
        <location filename="../src/panels/imagebrowserpanel.cpp" line="621"/>
        <source>No images</source>
        <translation>Нет изображений</translation>
    </message>
    <message>
        <location filename="../src/panels/imagebrowserpanel.cpp" line="623"/>
        <source>Download images</source>
        <translation>Загрузка изображений</translation>
    </message>
    <message>
        <location filename="../src/panels/imagebrowserpanel.cpp" line="901"/>
        <source>Error occured</source>
        <translation>Произошла ошибка</translation>
    </message>
    <message>
        <location filename="../src/panels/imagebrowserpanel.cpp" line="901"/>
        <source>Unknown window state</source>
        <translation>Неопределенное состояние окна</translation>
    </message>
</context>
<context>
    <name>MessageBrowser</name>
    <message>
        <location filename="../src/widgets/messagebrowser.ui" line="14"/>
        <source>Form</source>
        <translation>Форма</translation>
    </message>
    <message>
        <location filename="../src/widgets/messagebrowser.cpp" line="56"/>
        <source>Title:</source>
        <translation>Заголовок:</translation>
    </message>
    <message>
        <location filename="../src/widgets/messagebrowser.cpp" line="61"/>
        <source>From:</source>
        <translation>От кого:</translation>
    </message>
    <message>
        <location filename="../src/widgets/messagebrowser.cpp" line="187"/>
        <source>Date: </source>
        <translation>Дата: </translation>
    </message>
    <message>
        <location filename="../src/widgets/messagebrowser.cpp" line="191"/>
        <source>To: </source>
        <translation>Кому: </translation>
    </message>
    <message>
        <location filename="../src/widgets/messagebrowser.cpp" line="195"/>
        <location filename="../src/widgets/messagebrowser.cpp" line="198"/>
        <source>From: </source>
        <translation>От кого: </translation>
    </message>
    <message>
        <location filename="../src/widgets/messagebrowser.cpp" line="59"/>
        <source>Date:</source>
        <translation>Дата:</translation>
    </message>
    <message>
        <location filename="../src/widgets/messagebrowser.cpp" line="63"/>
        <source>To:</source>
        <translation>Кому:</translation>
    </message>
</context>
<context>
    <name>MessageBrowserPanel</name>
    <message>
        <location filename="../src/panels/messagebrowserpanel.ui" line="14"/>
        <source>Form</source>
        <translation>Форма</translation>
    </message>
    <message>
        <source>Title</source>
        <translation type="obsolete">Тема</translation>
    </message>
    <message>
        <source>Date</source>
        <translation type="obsolete">Дата</translation>
    </message>
    <message>
        <location filename="../src/panels/messagebrowserpanel.cpp" line="63"/>
        <location filename="../src/panels/messagebrowserpanel.cpp" line="434"/>
        <source>Messages (%1)</source>
        <translation>Сообщения (%1)</translation>
    </message>
    <message>
        <source>News</source>
        <translation type="obsolete">Новости</translation>
    </message>
    <message>
        <source>News (%1)</source>
        <translation type="obsolete">Обновления (%1)</translation>
    </message>
    <message>
        <location filename="../src/panels/messagebrowserpanel.cpp" line="364"/>
        <source>Error occured</source>
        <translation>Произошла ошибка</translation>
    </message>
    <message>
        <location filename="../src/panels/messagebrowserpanel.cpp" line="364"/>
        <source>Unknown window state</source>
        <translation>Неопределенное состояние окна</translation>
    </message>
</context>
<context>
    <name>MessageComposer</name>
    <message>
        <location filename="../src/widgets/messagecomposer.ui" line="14"/>
        <source>Form</source>
        <translation>Форма</translation>
    </message>
    <message>
        <location filename="../src/widgets/messagecomposer.ui" line="30"/>
        <source>Title:</source>
        <translation>Заголовок:</translation>
    </message>
    <message>
        <location filename="../src/widgets/messagecomposer.ui" line="40"/>
        <source>To:</source>
        <translation>Кому:</translation>
    </message>
    <message>
        <location filename="../src/widgets/messagecomposer.cpp" line="29"/>
        <source>Send</source>
        <translation>Отправить</translation>
    </message>
    <message>
        <location filename="../src/widgets/messagecomposer.cpp" line="33"/>
        <source>Save</source>
        <translation>Сохранить</translation>
    </message>
    <message>
        <location filename="../src/widgets/messagecomposer.cpp" line="110"/>
        <source>Re: %1</source>
        <translation></translation>
    </message>
</context>
<context>
    <name>NewsBrowserPanel</name>
    <message>
        <location filename="../src/panels/newsbrowserpanel.cpp" line="174"/>
        <source>News (%1)</source>
        <translation>Новости (%1)</translation>
    </message>
</context>
<context>
    <name>PhotoListWidget</name>
    <message>
        <location filename="../src/widgets/photolistwidget.cpp" line="97"/>
        <source>Copy to</source>
        <translation>Копировать в</translation>
    </message>
    <message>
        <location filename="../src/widgets/photolistwidget.cpp" line="116"/>
        <source>Select...</source>
        <translation>Выбрать...</translation>
    </message>
</context>
<context>
    <name>ProfileBrowser</name>
    <message>
        <location filename="../src/widgets/profilebrowser.ui" line="14"/>
        <source>Form</source>
        <translation>Форма</translation>
    </message>
    <message>
        <location filename="../src/widgets/profilebrowser.ui" line="37"/>
        <source>Photo</source>
        <translation>Изображение</translation>
    </message>
    <message>
        <location filename="../src/widgets/profilebrowser.ui" line="75"/>
        <location filename="../src/widgets/profilebrowser.ui" line="88"/>
        <source>TextLabel</source>
        <translation></translation>
    </message>
    <message>
        <source>First name:</source>
        <translation type="obsolete">Имя:</translation>
    </message>
    <message>
        <source>Nick:</source>
        <translation type="obsolete">Прозвище:</translation>
    </message>
    <message>
        <source>Last name:</source>
        <translation type="obsolete">Фамилия:</translation>
    </message>
    <message>
        <source>Gender:</source>
        <translation type="obsolete">Пол:</translation>
    </message>
    <message>
        <source>Birthday:</source>
        <translation type="obsolete">Дата рождения:</translation>
    </message>
    <message>
        <source>Mobile phone:</source>
        <translation type="obsolete">Мобильный телефон:</translation>
    </message>
    <message>
        <source>Home phone:</source>
        <translation type="obsolete">Стационарный телефон:</translation>
    </message>
    <message>
        <source>City:</source>
        <translation type="obsolete">Город:</translation>
    </message>
    <message>
        <source>Country:</source>
        <translation type="obsolete">Страна:</translation>
    </message>
    <message>
        <source>Places</source>
        <translation type="obsolete">Местоположение</translation>
    </message>
    <message>
        <location filename="../src/widgets/profilebrowser.cpp" line="112"/>
        <source>General</source>
        <translation>Основная информация</translation>
    </message>
    <message>
        <location filename="../src/widgets/profilebrowser.cpp" line="115"/>
        <source>Nickname: </source>
        <translation>Прозвище: </translation>
    </message>
    <message>
        <location filename="../src/widgets/profilebrowser.cpp" line="118"/>
        <source>Birthday: </source>
        <translation>День рождения: </translation>
    </message>
    <message>
        <location filename="../src/widgets/profilebrowser.cpp" line="122"/>
        <source>Gender: </source>
        <translation>Пол: </translation>
    </message>
    <message>
        <location filename="../src/widgets/profilebrowser.cpp" line="127"/>
        <source>Place</source>
        <translation>Местоположение</translation>
    </message>
    <message>
        <location filename="../src/widgets/profilebrowser.cpp" line="142"/>
        <source>Status</source>
        <translation>Статус</translation>
    </message>
    <message>
        <location filename="../src/widgets/profilebrowser.cpp" line="148"/>
        <source>Contacts</source>
        <translation>Контакты</translation>
    </message>
    <message>
        <location filename="../src/widgets/profilebrowser.h" line="87"/>
        <source>male</source>
        <translation>мужской</translation>
    </message>
    <message>
        <location filename="../src/widgets/profilebrowser.h" line="88"/>
        <source>female</source>
        <translation>женский</translation>
    </message>
</context>
<context>
    <name>ProfileBrowserPanel</name>
    <message>
        <location filename="../src/panels/profilebrowserpanel.ui" line="14"/>
        <source>Form</source>
        <translation>Форма</translation>
    </message>
    <message>
        <location filename="../src/panels/profilebrowserpanel.cpp" line="76"/>
        <source>Albums</source>
        <translation>Альбомы</translation>
    </message>
    <message>
        <location filename="../src/panels/profilebrowserpanel.cpp" line="88"/>
        <source>Messages</source>
        <translation>Сообщения</translation>
    </message>
    <message>
        <location filename="../src/panels/profilebrowserpanel.cpp" line="100"/>
        <source>Send message</source>
        <translation>Новое</translation>
    </message>
    <message>
        <source>News (%1)</source>
        <translation type="obsolete">Обновления (%1)</translation>
    </message>
    <message>
        <source>People</source>
        <translation type="obsolete">Друзья</translation>
    </message>
    <message>
        <location filename="../src/panels/profilebrowserpanel.cpp" line="62"/>
        <location filename="../src/panels/profilebrowserpanel.cpp" line="231"/>
        <source>People (%1)</source>
        <translation>Друзья (%1)</translation>
    </message>
    <message>
        <source>News</source>
        <translation type="obsolete">Новости</translation>
    </message>
    <message>
        <source>Type a name...</source>
        <translation type="obsolete">Введите имя...</translation>
    </message>
    <message>
        <source>No Friends</source>
        <translation type="obsolete">Нет друзей</translation>
    </message>
    <message>
        <source>Download friend list</source>
        <translation type="obsolete">Загрузка списка друзей</translation>
    </message>
    <message>
        <location filename="../src/panels/profilebrowserpanel.cpp" line="304"/>
        <source>Error occured</source>
        <translation>Произошла ошибка</translation>
    </message>
    <message>
        <location filename="../src/panels/profilebrowserpanel.cpp" line="304"/>
        <source>Unknown window state</source>
        <translation>Неопределенное состояние окна</translation>
    </message>
</context>
<context>
    <name>QAddComment</name>
    <message>
        <location filename="../src/widgets/qaddcomment.ui" line="14"/>
        <source>Add comment to image</source>
        <translation>Добавление комментария к изображению</translation>
    </message>
</context>
<context>
    <name>QDriversList</name>
    <message>
        <location filename="../src/widgets/qdriverslist.ui" line="14"/>
        <source>Form</source>
        <translation>Список драйверов</translation>
    </message>
</context>
<context>
    <name>QFriendDelegate</name>
    <message>
        <location filename="../src/widgets/friends/qfrienddelegate.cpp" line="72"/>
        <source>online</source>
        <translation>в сети</translation>
    </message>
</context>
<context>
    <name>QFriendListWidget</name>
    <message>
        <location filename="../src/widgets/friends/qfriendlistwidget.ui" line="14"/>
        <source>Form</source>
        <translation>Форма</translation>
    </message>
    <message>
        <location filename="../src/widgets/friends/qfriendlistwidget.cpp" line="25"/>
        <source>Type a name...</source>
        <translation>Введите имя...</translation>
    </message>
    <message>
        <location filename="../src/widgets/friends/qfriendlistwidget.cpp" line="63"/>
        <source>Me</source>
        <translation>Мое</translation>
    </message>
</context>
<context>
    <name>QImageViewer</name>
    <message>
        <location filename="../src/widgets/qimageviewer.cpp" line="99"/>
        <source>Comments</source>
        <translation>Комментарии</translation>
    </message>
    <message>
        <location filename="../src/widgets/qimageviewer.cpp" line="100"/>
        <source>Refresh comments</source>
        <translation>Обновить комментарии</translation>
    </message>
    <message>
        <location filename="../src/widgets/qimageviewer.cpp" line="102"/>
        <source>Add comment</source>
        <translation>Добавить комментарий</translation>
    </message>
    <message>
        <location filename="../src/widgets/qimageviewer.cpp" line="235"/>
        <source>Image Viewer</source>
        <translation>Программа просмотра изображений</translation>
    </message>
    <message>
        <location filename="../src/widgets/qimageviewer.cpp" line="236"/>
        <source>Cannot load %1.</source>
        <translation>Не удалось загрузить %1.</translation>
    </message>
    <message>
        <location filename="../src/widgets/qimageviewer.cpp" line="269"/>
        <source>Downloading image...</source>
        <translation>Загрузка изображения...</translation>
    </message>
</context>
<context>
    <name>QMessageListModel</name>
    <message>
        <location filename="../src/widgets/messages/qmessagelistmodel.cpp" line="81"/>
        <source>Title</source>
        <translation>Тема</translation>
    </message>
    <message>
        <location filename="../src/widgets/messages/qmessagelistmodel.cpp" line="83"/>
        <source>Date</source>
        <translation>Дата</translation>
    </message>
    <message>
        <location filename="../src/widgets/messages/qmessagelistmodel.cpp" line="85"/>
        <source>From/To</source>
        <translation>От/Кому</translation>
    </message>
</context>
<context>
    <name>QMessageListWidget</name>
    <message>
        <location filename="../src/widgets/messages/qmessagelistwidget.ui" line="14"/>
        <source>Form</source>
        <translation>Форма</translation>
    </message>
    <message>
        <source>Type a name...</source>
        <translation type="obsolete">Введите имя...</translation>
    </message>
    <message>
        <location filename="../src/widgets/messages/qmessagelistwidget.cpp" line="26"/>
        <source>Type a title...</source>
        <translation>Введите тему сообщения...</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <source>Unknown</source>
        <translation type="obsolete">Неизвестный</translation>
    </message>
</context>
<context>
    <name>QPhotoUploader</name>
    <message>
        <location filename="../src/widgets/qphotouploader.ui" line="20"/>
        <source>Images upload manager</source>
        <translation>Загрузчик изображений</translation>
    </message>
    <message>
        <location filename="../src/widgets/qphotouploader.ui" line="97"/>
        <source>Total upload size:</source>
        <translation>Полный размер загрузки:</translation>
    </message>
    <message>
        <location filename="../src/widgets/qphotouploader.ui" line="126"/>
        <source>New album</source>
        <translation>Новый альбом</translation>
    </message>
    <message>
        <location filename="../src/widgets/qphotouploader.ui" line="145"/>
        <source>Add files</source>
        <translation>Добавить файлы</translation>
    </message>
    <message>
        <location filename="../src/widgets/qphotouploader.ui" line="187"/>
        <source>Upload</source>
        <translation>Загрузить</translation>
    </message>
    <message>
        <location filename="../src/widgets/qphotouploader.ui" line="194"/>
        <location filename="../src/widgets/qphotouploader.cpp" line="191"/>
        <source>Cancel</source>
        <translation>Отменить</translation>
    </message>
    <message>
        <location filename="../src/widgets/qphotouploader.cpp" line="32"/>
        <source>Add description</source>
        <translation>Добавить описание</translation>
    </message>
    <message>
        <location filename="../src/widgets/qphotouploader.cpp" line="33"/>
        <source>Delete</source>
        <translation>Удалить</translation>
    </message>
    <message>
        <location filename="../src/widgets/qphotouploader.cpp" line="51"/>
        <source>No active accounts</source>
        <translation>Нет активных учётных записей</translation>
    </message>
    <message numerus="yes">
        <location filename="../src/widgets/qphotouploader.cpp" line="117"/>
        <location filename="../src/widgets/qphotouploader.cpp" line="440"/>
        <source>%1 photo(s)</source>
        <translation>
            <numerusform>%1 изображение</numerusform>
            <numerusform>%1 изображения</numerusform>
            <numerusform>%1 изображений</numerusform>
        </translation>
    </message>
    <message>
        <location filename="../src/widgets/qphotouploader.cpp" line="120"/>
        <source>No avalible albums</source>
        <translation>Нет доступных альбомов</translation>
    </message>
    <message>
        <location filename="../src/widgets/qphotouploader.cpp" line="158"/>
        <source>bytes</source>
        <translation>байт</translation>
    </message>
    <message>
        <location filename="../src/widgets/qphotouploader.cpp" line="160"/>
        <source>Kbytes</source>
        <translation>Кбайт</translation>
    </message>
    <message>
        <location filename="../src/widgets/qphotouploader.cpp" line="161"/>
        <source>Mbytes</source>
        <translation>Мбайт</translation>
    </message>
    <message>
        <location filename="../src/widgets/qphotouploader.cpp" line="168"/>
        <source>Open Image</source>
        <translation>Открыть изображение</translation>
    </message>
    <message>
        <location filename="../src/widgets/qphotouploader.cpp" line="169"/>
        <location filename="../src/widgets/qphotouploader.cpp" line="187"/>
        <source>Images</source>
        <translation>Изображения</translation>
    </message>
    <message>
        <location filename="../src/widgets/qphotouploader.cpp" line="188"/>
        <source>Look in:</source>
        <translation>Расположение:</translation>
    </message>
    <message>
        <location filename="../src/widgets/qphotouploader.cpp" line="189"/>
        <source>File name:</source>
        <translation>Имя файла:</translation>
    </message>
    <message>
        <location filename="../src/widgets/qphotouploader.cpp" line="190"/>
        <source>File types:</source>
        <translation>Типы файлов:</translation>
    </message>
    <message>
        <location filename="../src/widgets/qphotouploader.cpp" line="192"/>
        <source>Add</source>
        <translation>Добавить</translation>
    </message>
    <message>
        <location filename="../src/widgets/qphotouploader.cpp" line="344"/>
        <source>Enter descripton:</source>
        <translation>Введить описание:</translation>
    </message>
    <message>
        <location filename="../src/widgets/qphotouploader.cpp" line="420"/>
        <source>Creating album</source>
        <translation>Создание альбома</translation>
    </message>
    <message>
        <location filename="../src/widgets/qphotouploader.cpp" line="421"/>
        <source>Enter name of the album:</source>
        <translation>Введите имя альбома:</translation>
    </message>
</context>
<context>
    <name>QStatWidget</name>
    <message>
        <source>Form</source>
        <translation type="obsolete">Форма</translation>
    </message>
    <message>
        <source>TextLabel</source>
        <translation type="obsolete">Текст</translation>
    </message>
    <message>
        <location filename="../src/widgets/qstatwidget.cpp" line="32"/>
        <source>byte(s)</source>
        <translation>байт</translation>
    </message>
    <message>
        <location filename="../src/widgets/qstatwidget.cpp" line="33"/>
        <source>kilobyte(s)</source>
        <translation>килобайт</translation>
    </message>
    <message>
        <location filename="../src/widgets/qstatwidget.cpp" line="34"/>
        <source>megabyte(s)</source>
        <translation>мегабайт</translation>
    </message>
    <message>
        <location filename="../src/widgets/qstatwidget.cpp" line="35"/>
        <source>gigabyte(s)</source>
        <translation>гигабайт</translation>
    </message>
    <message>
        <location filename="../src/widgets/qstatwidget.cpp" line="36"/>
        <source>terabyte(s)</source>
        <translation>терабайт</translation>
    </message>
    <message>
        <location filename="../src/widgets/qstatwidget.cpp" line="47"/>
        <source>Common statistics</source>
        <translation>Общая статистика</translation>
    </message>
    <message>
        <location filename="../src/widgets/qstatwidget.cpp" line="48"/>
        <source>Account statistics</source>
        <translation>Статистика учетных записей</translation>
    </message>
    <message>
        <location filename="../src/widgets/qstatwidget.cpp" line="72"/>
        <location filename="../src/widgets/qstatwidget.cpp" line="79"/>
        <source>Requests</source>
        <translation>Число запросов</translation>
    </message>
    <message>
        <location filename="../src/widgets/qstatwidget.cpp" line="73"/>
        <location filename="../src/widgets/qstatwidget.cpp" line="80"/>
        <source>Download</source>
        <translation>Загружено</translation>
    </message>
    <message>
        <location filename="../src/widgets/qstatwidget.cpp" line="74"/>
        <location filename="../src/widgets/qstatwidget.cpp" line="81"/>
        <source>Upload</source>
        <translation>Отправлено</translation>
    </message>
    <message>
        <location filename="../src/widgets/qstatwidget.cpp" line="75"/>
        <location filename="../src/widgets/qstatwidget.cpp" line="82"/>
        <source>Errors</source>
        <translation>Число ошибок</translation>
    </message>
    <message>
        <source>VKGallery - Help</source>
        <translation type="obsolete">VKGallery - Справка</translation>
    </message>
    <message>
        <location filename="../src/widgets/qstatwidget.ui" line="14"/>
        <source>Statistics</source>
        <translation>Статистика</translation>
    </message>
</context>
<context>
    <name>QTransport</name>
    <message>
        <source>Caught an exception.</source>
        <translation type="obsolete">Произошла ошибка.</translation>
    </message>
    <message>
        <source>Bad response from driver</source>
        <translation type="obsolete">Некорректный ответ от драйвера</translation>
    </message>
    <message>
        <source>Unsupported method was called</source>
        <translation type="obsolete">Вызван неподдерживаемый метод</translation>
    </message>
    <message>
        <source>This method didn&apos;t supported by selected driver</source>
        <translation type="obsolete">Метод не поддерживается выбранным драйвером</translation>
    </message>
    <message>
        <source>Can&apos;t read file to upload</source>
        <translation type="obsolete">Не удалось открыть отправляемый на сервис файл</translation>
    </message>
    <message>
        <source>QTransport::downloadPhotoLost() with nearest &lt; 0</source>
        <translation type="obsolete">QTransport::downloadPhotoLost() с параметром nearest &lt; 0</translation>
    </message>
    <message>
        <source>Wrong arguments of function</source>
        <translation type="obsolete">Неправильные аргументы функции</translation>
    </message>
    <message>
        <source>Unable to save settings</source>
        <translation type="obsolete">Не удалось сохранить настройки</translation>
    </message>
    <message>
        <source>Authorization problem</source>
        <translation type="obsolete">Проблема авторизации</translation>
    </message>
    <message>
        <source>Authorization canceled</source>
        <translation type="obsolete">Авторизация прервана</translation>
    </message>
    <message>
        <source>Unable to perform request</source>
        <translation type="obsolete">Невозможно выполнить запрос</translation>
    </message>
    <message>
        <source>Server busy</source>
        <translation type="obsolete">Сервер занят</translation>
    </message>
    <message>
        <source>One of the parameters missing or invalid</source>
        <translation type="obsolete">Один из параметров пропущен или неверен</translation>
    </message>
    <message>
        <source>Captcha</source>
        <translation type="obsolete">Требуется ввод каптчи</translation>
    </message>
    <message>
        <source>Bad response from server</source>
        <translation type="obsolete">Некорректный ответ от сервера</translation>
    </message>
    <message>
        <source>Network problem</source>
        <translation type="obsolete">Проблема соединения с сервером</translation>
    </message>
    <message>
        <source>Empty message</source>
        <translation type="obsolete">Пустое сообщение</translation>
    </message>
    <message>
        <source>Operation prohibited by privacy</source>
        <translation type="obsolete">Операция запрещена приватностью</translation>
    </message>
    <message>
        <source>Internal Server Error</source>
        <translation type="obsolete">Внутренняя ошибка сервера</translation>
    </message>
    <message>
        <source>Can&apos;t save file</source>
        <translation type="obsolete">Не удалось сохранить файл</translation>
    </message>
    <message>
        <source>male</source>
        <translation type="obsolete">мужской</translation>
    </message>
    <message>
        <source>female</source>
        <translation type="obsolete">женский</translation>
    </message>
    <message>
        <source>Incorrect signature</source>
        <translation type="obsolete">Информация об авторизации неверная или устарела</translation>
    </message>
</context>
<context>
    <name>ServiceFilter</name>
    <message>
        <source>All</source>
        <translation type="obsolete">Все</translation>
    </message>
</context>
<context>
    <name>ServiceMgr</name>
    <message>
        <source>During request </source>
        <translation type="obsolete">В ходе запроса </translation>
    </message>
    <message>
        <source>&quot;Update list of friends&quot;</source>
        <translation type="obsolete">&quot;Обновление списка друзей&quot;</translation>
    </message>
    <message>
        <source>&quot;Delete friend from list&quot;</source>
        <translation type="obsolete">&quot;Удаление друга из списка&quot;</translation>
    </message>
    <message>
        <source>&quot;Update list of albums&quot;</source>
        <translation type="obsolete">&quot;Обновление списка альбомов&quot;</translation>
    </message>
    <message>
        <source>&quot;Update list of images&quot;</source>
        <translation type="obsolete">&quot;Обновление списка изображений&quot;</translation>
    </message>
    <message>
        <source>&quot;Update user profile&quot;</source>
        <translation type="obsolete">&quot;Обновление профиля пользователя&quot;</translation>
    </message>
    <message>
        <source>Account swiched to offline mode. Please check network settings and try again.</source>
        <translation type="obsolete">Учетная запись переключена в автономный режим. Пожалуйста, проверьте настройки соединения и попробуйте снова.</translation>
    </message>
    <message>
        <source>&quot;Get settings&quot;</source>
        <translation type="obsolete">&quot;Получение настроек&quot;</translation>
    </message>
    <message>
        <source>&quot;Set settings&quot;</source>
        <translation type="obsolete">&quot;Применение настроек&quot;</translation>
    </message>
    <message>
        <source>&quot;Download image&quot;</source>
        <translation type="obsolete">&quot;Получение изображения&quot;</translation>
    </message>
    <message>
        <source>&quot;Upload image&quot;</source>
        <translation type="obsolete">&quot;Загрузка изображения на сервис&quot;</translation>
    </message>
    <message>
        <source>&quot;Get comments&quot;</source>
        <translation type="obsolete">&quot;Получение комментариев&quot;</translation>
    </message>
    <message>
        <source>&quot;Send comment&quot;</source>
        <translation type="obsolete">&quot;Отправка комментария&quot;</translation>
    </message>
    <message>
        <source>&quot;Get list of messages&quot;</source>
        <translation type="obsolete">&quot;Получение сообщений&quot;</translation>
    </message>
    <message>
        <source>&quot;Get message inbox&quot;</source>
        <translation type="obsolete">&quot;Получение списка входящих сообщений&quot;</translation>
    </message>
    <message>
        <source>&quot;Get message outbox&quot;</source>
        <translation type="obsolete">&quot;Получение списка отправленных сообщений&quot;</translation>
    </message>
    <message>
        <source>&quot;Send message&quot;</source>
        <translation type="obsolete">&quot;Отправка сообщения&quot;</translation>
    </message>
    <message>
        <source>&quot;Mark message as read&quot;</source>
        <translation type="obsolete">&quot;Пометка сообщения прочитанным&quot;</translation>
    </message>
    <message>
        <source>&quot;Delete message&quot;</source>
        <translation type="obsolete">&quot;Удаление сообщения&quot;</translation>
    </message>
    <message>
        <source>&quot;Get list of registered methods&quot;</source>
        <translation type="obsolete">&quot;Получение списка поддерживаемых методов&quot;</translation>
    </message>
    <message>
        <source>&quot;Get feed&quot;</source>
        <translation type="obsolete">Получение новостей</translation>
    </message>
    <message>
        <source> from account &quot;%1&quot; the error %2 was caused: </source>
        <translation type="obsolete"> от учетной записи &quot;%1&quot; получена ошибка %2: </translation>
    </message>
</context>
<context>
    <name>UIAccountSettings</name>
    <message>
        <location filename="../src/widgets/uiaccountsettings.ui" line="20"/>
        <source>Settings</source>
        <translation>Настройки</translation>
    </message>
    <message>
        <location filename="../src/widgets/uiaccountsettings.ui" line="42"/>
        <source>Add</source>
        <translation>Добавить</translation>
    </message>
    <message>
        <location filename="../src/widgets/uiaccountsettings.ui" line="52"/>
        <source>Remove</source>
        <translation>Удалить</translation>
    </message>
    <message>
        <location filename="../src/widgets/uiaccountsettings.ui" line="62"/>
        <source>Reconnect</source>
        <translation>Переподключиться</translation>
    </message>
    <message>
        <location filename="../src/widgets/uiaccountsettings.ui" line="72"/>
        <location filename="../src/widgets/uiaccountsettings.cpp" line="70"/>
        <source>Disable</source>
        <translation>Отключить</translation>
    </message>
    <message>
        <location filename="../src/widgets/uiaccountsettings.cpp" line="38"/>
        <source> (offline mode)</source>
        <translation> (автономный режим)</translation>
    </message>
    <message>
        <location filename="../src/widgets/uiaccountsettings.cpp" line="40"/>
        <source>disabled</source>
        <translation>отключен</translation>
    </message>
    <message>
        <location filename="../src/widgets/uiaccountsettings.cpp" line="73"/>
        <source>Enable</source>
        <translation>Включить</translation>
    </message>
</context>
<context>
    <name>UIAddAccount</name>
    <message>
        <location filename="../src/widgets/uiaddaccount.ui" line="20"/>
        <source>Add new account</source>
        <translation>Добавление новой учетной записи</translation>
    </message>
    <message>
        <location filename="../src/widgets/uiaddaccount.ui" line="51"/>
        <source>Account name:</source>
        <translation>Название учетной записи:</translation>
    </message>
    <message>
        <location filename="../src/widgets/uiaddaccount.cpp" line="22"/>
        <source>Input account name and select one of services</source>
        <translation>Введите имя учетной записи и выберите один из сервисов</translation>
    </message>
    <message>
        <location filename="../src/widgets/uiaddaccount.cpp" line="34"/>
        <source>Input name of service!</source>
        <translation>Введите имя учетной записи!</translation>
    </message>
    <message>
        <location filename="../src/widgets/uiaddaccount.cpp" line="40"/>
        <source>This account name already exists!</source>
        <translation>Такое имя учетной записи уже существует!</translation>
    </message>
    <message>
        <location filename="../src/widgets/uiaddaccount.cpp" line="46"/>
        <source>Select one of services!</source>
        <translation>Выберите один из сервисов!</translation>
    </message>
</context>
<context>
    <name>UINetworkSettings</name>
    <message>
        <location filename="../src/widgets/uinetworksettings.ui" line="20"/>
        <source>Settings</source>
        <translation>Настройки</translation>
    </message>
    <message>
        <location filename="../src/widgets/uinetworksettings.ui" line="39"/>
        <source>Proxy:</source>
        <translation>Прокси:</translation>
    </message>
    <message>
        <location filename="../src/widgets/uinetworksettings.ui" line="49"/>
        <source>No Proxy</source>
        <translation>Без прокси</translation>
    </message>
    <message>
        <location filename="../src/widgets/uinetworksettings.ui" line="65"/>
        <source>System</source>
        <translation>Системный</translation>
    </message>
    <message>
        <location filename="../src/widgets/uinetworksettings.ui" line="72"/>
        <source>Manual</source>
        <translation>Вручную</translation>
    </message>
    <message>
        <location filename="../src/widgets/uinetworksettings.ui" line="128"/>
        <source>Address:</source>
        <translation>Адрес:</translation>
    </message>
    <message>
        <location filename="../src/widgets/uinetworksettings.ui" line="144"/>
        <source>Port:</source>
        <translation>Порт:</translation>
    </message>
</context>
<context>
    <name>uihelp</name>
    <message>
        <location filename="../src/widgets/uihelp.ui" line="14"/>
        <source>VKGallery - Help</source>
        <translation>VKGallery - Справка</translation>
    </message>
    <message>
        <location filename="../src/widgets/uihelp.ui" line="28"/>
        <source>file:///</source>
        <translation></translation>
    </message>
    <message>
        <source>/help.html</source>
        <translation type="obsolete">/help_ru.html</translation>
    </message>
    <message>
        <source>/about.html</source>
        <translation type="obsolete">/about_ru.html</translation>
    </message>
</context>
</TS>
